data.base

data.base

Classes

Name Description
Config Base class for all configurations.
FileConfig Base class for configurations that are stored in a local file.

Config

data.base.Config()

Base class for all configurations.

All configurations inherit from this class, be they stored in a file or generated on the fly.

Attributes

Name Type Description
desc str The description from the docstring.
_repr_content dict The items that are displayed in the repr method.

FileConfig

data.base.FileConfig(filename, directory=None, **desc)

Base class for configurations that are stored in a local file.

Parameters

Name Type Description Default
filename str The file’s name. required
directory Optional[str] The directory where the file is contained. Defaults to the location of the datasets module. None
desc dict Extra config parameters to pass as keyword arguments. {}

Attributes

Name Description
path The path to the configuration file.