factor_analyzer.factor_analyzer.calculate_bartlett_sphericity

factor_analyzer.factor_analyzer.calculate_bartlett_sphericity(x)

Compute the Bartlett sphericity test.

H0: The matrix of population correlations is equal to I. H1: The matrix of population correlations is not equal to I.

The formula for Bartlett’s Sphericity test is:

.. math:: -1 * (n - 1 - ((2p + 5) / 6)) * ln(det(R))

Where R det(R) is the determinant of the correlation matrix, and p is the number of variables.

Parameters

Name Type Description Default
x array - like The array for which to calculate sphericity. required

Returns

Name Type Description
statistic float The chi-square value.
p_value float The associated p-value for the test.