factor_analyzer.factor_analyzer_utils.fill_lower_diag

factor_analyzer.factor_analyzer_utils.fill_lower_diag(x)

Fill the lower diagonal of a square matrix, given a 1-D input array.

Parameters

Name Type Description Default
x array - like The flattened input matrix that will be used to fill the lower diagonal of the square matrix. required

Returns

Name Type Description
out :obj:numpy.ndarray The output square matrix, with the lower diagonal filled by x.

References

[1] https://stackoverflow.com/questions/51439271/ convert-1d-array-to-lower-triangular-matrix