factor_analyzer.factor_analyzer_utils.get_first_idxs_from_values

factor_analyzer.factor_analyzer_utils.get_first_idxs_from_values(
    x,
    eq=1,
    use_columns=True,
)

Get the indexes for a given value.

Parameters

Name Type Description Default
x array - like The input matrix. required
eq str or int The given value to find. Defaults to 1. 1
use_columns bool Whether to get the first indexes using the columns. If False, then use the rows instead. Defaults to True. True

Returns

Name Type Description
tuple Tuple[List[int], List[int]] - row_idx (list): A list of row indexes. - col_idx (list): A list of column indexes.