factor_analyzer.factor_analyzer_utils.get_free_parameter_idxs

factor_analyzer.factor_analyzer_utils.get_free_parameter_idxs(x, eq=1)

Get the free parameter indices from the flattened matrix.

Parameters

Name Type Description Default
x array - like The input matrix. required
eq str or int The value that free parameters should be equal to. np.nan fields will be populated with this value. Defaults to 1. 1

Returns

Name Type Description
idx :obj:numpy.ndarray The free parameter indexes.