factor_analyzer.factor_analyzer_utils.get_symmetric_lower_idxs

factor_analyzer.factor_analyzer_utils.get_symmetric_lower_idxs(n=1, diag=True)

Get the indices for the lower triangle of a symmetric matrix.

Parameters

Name Type Description Default
n int The dimension of the n x n symmetric matrix. Defaults to 1. 1
diag bool Whether to include the diagonal. True

Returns

Name Type Description
indices :obj:numpy.ndarray The indices for the lower triangle.