factor_analyzer.factor_analyzer_utils.merge_variance_covariance

factor_analyzer.factor_analyzer_utils.merge_variance_covariance(
    variances,
    covariances=None,
)

Merge variances and covariances into a single variance-covariance matrix.

Parameters

Name Type Description Default
variances array - like The variances that will be used to fill the diagonal of the square matrix. required
covariances array - like or None The flattened input matrix that will be used to fill the lower and upper diagonal of the square matrix. If None, then only the variances will be used. Defaults to None. None

Returns

Name Type Description
variance_covariance :obj:numpy.ndarray The variance-covariance matrix.