factor_analyzer.factor_analyzer_utils.smc

factor_analyzer.factor_analyzer_utils.smc(corr_mtx, sort=False)

Calculate the squared multiple correlations.

This is equivalent to regressing each variable on all others and calculating the r-squared values.

Parameters

Name Type Description Default
corr_mtx array - like The correlation matrix used to calculate SMC. required
sort bool Whether to sort the values for SMC before returning. Defaults to False. False

Returns

Name Type Description
smc numpy.ndarray The squared multiple correlations matrix.