function.mo.fun_myer16a

function.mo.fun_myer16a(X, fun_control=None)

Compute both conversion and activity predictions for each row in the input array.

Notes

Implements a response surface experiment described by Myers, Montgomery, and Anderson-Cook (2016). The function computes two objectives: conversion and activity.

References

  • Myers, R. H., Montgomery, D. C., and Anderson-Cook, C. M. Response surface methodology: process and product optimization using designed experiments. John Wiley & Sons, 2016.
  • Kuhn, M. desirability: Function optimization and ranking via desirability functions. Tech. rep., 9 2016.

Parameters

Name Type Description Default
X np.ndarray 2D array where each row is a configuration. required
fun_control dict Additional control parameters (not used here). None

Returns

Name Type Description
np.ndarray np.ndarray: 2D array where each row contains [conversion_pred, activity_pred].

Examples

>>> import numpy as np
>>> from spotoptim.function.mo import fun_myer16a
>>> # Example input data
>>> X = np.array([[1, 2, 3], [4, 5, 6]])
>>> fun_myer16a(X)
array([[  3.5,   1.5],
       [ 19.5,  10.5]])