function.so.wingwt

function.so.wingwt(X)

Aircraft Wing Weight function.

The example models the weight of an unpainted light aircraft wing. The function accepts inputs in the unit cube [0,1]^9 and returns the wing weight.

Parameters

Name Type Description Default
X array - like Input points with shape (n_samples, 9) or (9,) or (10,) or (n_samples, 10). Input variables order: [Sw, Wfw, A, L, q, l, Rtc, Nz, Wdg, Wp(optional)] required

Returns

Name Type Description
np.ndarray np.ndarray: Wing weight values at the input points with shape (n_samples,).

Examples

Single point evaluation (Baseline Cessna C172 - Unpainted):

from spotoptim.function.so import wingwt
import numpy as np
# Baseline configuration in unit cube
x_base = np.array([0.48, 0.4, 0.38, 0.5, 0.62, 0.344, 0.4, 0.37, 0.38])
wingwt(x_base)
array([233.90840542])

Batch evaluation:

from spotoptim.function.so import wingwt
import numpy as np
x_base = np.array([0.48, 0.4, 0.38, 0.5, 0.62, 0.344, 0.4, 0.37, 0.38])
X = np.vstack([x_base, x_base])
wingwt(X)
array([233.90840542, 233.90840542])

References

Forrester, A., Sobester, A., & Keane, A. (2008). Engineering design via surrogate modelling: a practical guide. John Wiley & Sons.