mo.pareto.mo_pareto_optx_plot

mo.pareto.mo_pareto_optx_plot(
    X,
    Y,
    minimize=True,
    feature_names=None,
    target_names=None,
    **kwargs,
)

Visualizes the Pareto-optimal points in the input space for each pair of inputs x_i and x_j (with i < j) and each objective f_k.

Plots are placed on a grid where rows correspond to input pairs and columns correspond to objectives.

Parameters

Name Type Description Default
X np.ndarray An (N,D) array of input points, where N is the number of points and D is the number of variables (dimensions). required
Y np.ndarray An (N,M) array of objective values, where N is the number of points and M is the number of objectives. required
minimize bool If True, assumes minimization of objectives. Defaults to True. True
feature_names list List of names for the input variables. Defaults to None. None
target_names list List of names for the objectives. Defaults to None. None
**kwargs Any Additional arguments passed to plt.subplots (e.g., figsize). {}

Returns

Name Type Description
None None

Examples

>>> from spotoptim.mo.pareto import mo_pareto_optx_plot
>>> X = np.array([[1, 2], [3, 4], [5, 6]])
>>> Y = np.array([[1, 2], [3, 4], [5, 6]])
>>> mo_pareto_optx_plot(X, Y)