plot.contour.mo_generate_plot_grid

plot.contour.mo_generate_plot_grid(variables, resolutions, functions)

Generate a grid of input variables and apply objective functions.

Parameters

Name Type Description Default
variables dict A dictionary where keys are variable names (e.g., “time”, “temperature”) and values are tuples of (min_value, max_value). required
resolutions dict A dictionary where keys are variable names and values are the number of points. required
functions dict A dictionary where keys are function names and values are callable functions. required

Returns

Name Type Description
pd.DataFrame pd.DataFrame: A DataFrame containing the grid and the results of the objective functions.