sampling.mm.plot_mmphi_vs_n_lhs

sampling.mm.plot_mmphi_vs_n_lhs(
    k_dim,
    seed,
    n_min=10,
    n_max=100,
    n_step=5,
    q_phi=2.0,
    p_phi=2.0,
)

Generates LHS designs for varying n, calculates mmphi and mmphi_intensive, and plots them against the number of samples (n).

Parameters

Name Type Description Default
k_dim int Number of dimensions for the LHS design. required
seed int Random seed for reproducibility. required
n_min int Minimum number of samples. 10
n_max int Maximum number of samples. 100
n_step int Step size for increasing n. 5
q_phi float Exponent q for the Morris-Mitchell criteria. 2.0
p_phi float Distance norm p for the Morris-Mitchell criteria. 2.0

Returns

Name Type Description
None None Displays a plot of mmphi and mmphi_intensive vs. number of samples (n).

Examples

>>> from spotoptim.sampling.mm import plot_mmphi_vs_n_lhs
>>> plot_mmphi_vs_n_lhs(k_dim=3, seed=42, n_min=10, n_max=50, n_step=5, q_phi=2.0, p_phi=2.0)