sampling.mm.plot_mmphi_vs_points

sampling.mm.plot_mmphi_vs_points(
    X_base,
    x_min,
    x_max,
    p_min=10,
    p_max=100,
    p_step=10,
    n_repeats=5,
    figsize=(10, 6),
)

Plot the Morris-Mitchell criterion versus the number of added points.

Parameters

Name Type Description Default
X_base np.ndarray Base design matrix required
x_min np.ndarray Lower bounds for variables required
x_max np.ndarray Upper bounds for variables required
p_min int Minimum number of points to add 10
p_max int Maximum number of points to add 100
p_step int Step size for number of points 10
n_repeats int Number of repetitions for each point count 5
figsize tuple Size of the plot (width, height) (10, 6)

Returns

Name Type Description
pd.DataFrame pd.DataFrame: Summary DataFrame with mean and std of mmphi for each number of added points.

Examples

>>> import numpy as np
>>> from spotoptim.sampling.mm import plot_mmphi_vs_points
>>> # Define base design
>>> X_base = np.array([[0.1, 0.2], [0.4, 0.5], [0.7, 0.8]])
>>> # Define variable bounds
>>> x_min = np.array([0.0, 0.0])
>>> x_max = np.array([1.0, 1.0])
>>> # Plot mmphi vs number of added points
>>> df_summary = plot_mmphi_vs_points(X_base, x_min, x_max, p_min=10, p_max=50, p_step=10, n_repeats=3)