tricands.tricands.tricands_fringe

tricands.tricands.tricands_fringe(X, p=0.5, lower=0, upper=1)

Generate fringe candidates outside the convex hull.

Subroutine used by tricands wrapper. Assumes a bounding box of [lower, upper]^m.

Parameters

Name Type Description Default
X np.ndarray Input design matrix of shape (n_samples, n_features). required
p float Distance to the boundary (0 = on hull, 1 = on boundary). Defaults to 0.5. 0.5
lower float Lower bound of bounding box for all dimensions. Defaults to 0. 0
upper float Upper bound of bounding box for all dimensions. Defaults to 1. 1

Returns

Name Type Description
dict dict A dictionary containing: - ‘XF’ (np.ndarray): Fringe candidate points. - ‘XB’ (np.ndarray): Boundary points (means of external facets). - ‘qhull’ (scipy.spatial.ConvexHull): The computed convex hull object.

Raises

Name Type Description
Exception If the number of points is less than n_features + 1.