utils.file
utils.file
Functions
| Name | Description |
|---|---|
| get_experiment_filename | Generates a standardized filename for experiments. |
| get_internal_datasets_folder | Returns the absolute path to the internal datasets folder. |
get_experiment_filename
utils.file.get_experiment_filename(
PREFIX=None,
fun_name=None,
dim=None,
fun_evals=None,
path='experiments',
extension='pkl',
)Generates a standardized filename for experiments.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| PREFIX | str | Prefix/identifier for the experiment | None |
| fun_name | str | Name of the objective function | None |
| dim | int | Dimensionality of the problem | None |
| fun_evals | int | Number of function evaluations | None |
| path | str | Directory path to save the file | 'experiments' |
| extension | str | File extension (default: “pkl”) | 'pkl' |
Returns
| Name | Type | Description |
|---|---|---|
| str | str | Absolute path to the experiment file |
get_internal_datasets_folder
utils.file.get_internal_datasets_folder()Returns the absolute path to the internal datasets folder.
Returns
| Name | Type | Description |
|---|---|---|
| str | str | Absolute path to the datasets folder. |