data.base.Config
data.base.Config()Base class for all configurations.
All configurations inherit from this class, be they stored in a file or generated on the fly.
Attributes
| Name | Type | Description |
|---|---|---|
| desc | str | The description from the docstring. |
| _repr_content | dict | The items that are displayed in the repr method. |