factor_analyzer.factor_analyzer.calculate_kmo
factor_analyzer.factor_analyzer.calculate_kmo(x)Calculate the Kaiser-Meyer-Olkin criterion for items and overall.
This statistic represents the degree to which each observed variable is predicted, without error, by the other variables in the dataset. In general, a KMO < 0.6 is considered inadequate.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| x | array - like |
The array from which to calculate KMOs. | required |
Returns
| Name | Type | Description |
|---|---|---|
| kmo_per_variable | numpy.ndarray | The KMO score per item. |
| kmo_total | float | The overall KMO score. |