factor_analyzer.factor_analyzer_utils.cov
factor_analyzer.factor_analyzer_utils.cov(x, ddof=0)Calculate the covariance matrix.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| x | array - like |
A 1-D or 2-D array containing multiple variables and observations. Each column of x represents a variable, and each row a single observation of all those variables. | required |
| ddof | int | Means Delta Degrees of Freedom. The divisor used in calculations is N - ddof, where N represents the number of elements. Defaults to 0. | 0 |
Returns
| Name | Type | Description |
|---|---|---|
| r | numpy.ndarray | The covariance matrix of the variables. |