factor_analyzer.factor_analyzer_utils.inv_chol
factor_analyzer.factor_analyzer_utils.inv_chol(x, logdet=False)Calculate matrix inverse using Cholesky decomposition.
Optionally, calculate the log determinant of the Cholesky.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| x | array - like |
The matrix to invert. | required |
| logdet | bool | Whether to calculate the log determinant, instead of the inverse. Defaults to False. | False |
Returns
| Name | Type | Description |
|---|---|---|
| tuple | Tuple[np.ndarray, Optional[float]] | - chol_inv (array-like): The inverted matrix. - chol_logdet (array-like or None): The log determinant, if logdet was True, otherwise None. |