factor_analyzer.factor_analyzer_utils.partial_correlations
factor_analyzer.factor_analyzer_utils.partial_correlations(x)Compute partial correlations between variable pairs.
This is a python port of the pcor() function implemented in the ppcor R package, which computes partial correlations for each pair of variables in the given array, excluding all other variables.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| x | array - like |
An array containing the feature values. | required |
Returns
| Name | Type | Description |
|---|---|---|
| pcor | :obj:numpy.ndarray |
An array containing the partial correlations of of each pair of variables in the given array, excluding all other variables. |