Computes the drag coefficient (cd) of an aerofoil based on the shape parameter X.
This function reads the drag coefficient data from the “cd_data.csv” file and uses the input X (rounded to the nearest 0.01) to return the corresponding drag coefficients.