If 1, places centers of the extreme bins at the domain edges ([0,1]). Otherwise, bins are fully contained within the domain, i.e. midpoints. Defaults to 0.
A list of q values to optimize. Defaults to [1, 2, 5, 10, 20, 50, 100]. These values are used to evaluate the space-fillingness of the Latin hypercube. The best plan is selected based on the lowest mmphi value.
np.ndarray: A 2D array of shape (n, k) representing an optimized Latin hypercube.
Examples
>>>import numpy as np>>>from spotoptim.sampling.mm import bestlh# Generate a 5-point, 2-dimensional Latin hypercube>>> X = bestlh(n=5, k=2, population=5, iterations=10)>>>print(X.shape)(5, 2)